"""
Collection API
"""

from typing import Optional, Dict, Any
from .base import BaseAPI


class CollectionAPI(BaseAPI):
    """Collection endpoints"""
    
    def list_sessions(
        self,
        page: int = 1,
        page_size: int = 20,
    ) -> Dict[str, Any]:
        """List collection sessions"""
        params = {"page": page, "page_size": min(page_size, 100)}
        return self.client._request("GET", "collection/sessions", params=params)
